@@ -1,7 +1,8 @@
 /*
     connection.c -- connection list management
-    Copyright (C) 2000-2007 Guus Sliepen <guus@tinc-vpn.org>,
+    Copyright (C) 2000-2009 Guus Sliepen <guus@tinc-vpn.org>,
                   2000-2005 Ivo Timmermans
+                  2008      Max Rijevski <maksuf@gmail.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,11 +14,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    $Id: connection.c 1600 2008-12-23 23:14:37Z guus $
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include "system.h"
@@ -35,35 +34,25 @@
 avl_tree_t *connection_tree;	/* Meta connections */
 connection_t *broadcast;
 
-static int connection_compare(const connection_t *a, const connection_t *b)
-{
-	return (void *)a - (void *)b;
+static int connection_compare(const connection_t *a, const connection_t *b) {
+	return a < b ? -1 : a == b ? 0 : 1;
 }
 
-void init_connections(void)
-{
-	cp();
-
+void init_connections(void) {
 	connection_tree = avl_alloc_tree((avl_compare_t) connection_compare, (avl_action_t) free_connection);
 	broadcast = new_connection();
-	broadcast->name = xstrdup(_("everyone"));
-	broadcast->hostname = xstrdup(_("BROADCAST"));
+	broadcast->name = xstrdup("everyone");
+	broadcast->hostname = xstrdup("BROADCAST");
 }
 
-void exit_connections(void)
-{
-	cp();
-
+void exit_connections(void) {
 	avl_delete_tree(connection_tree);
 	free_connection(broadcast);
 }
 
-connection_t *new_connection(void)
-{
+connection_t *new_connection(void) {
 	connection_t *c;
 
-	cp();
-
 	c = xmalloc_and_zero(sizeof(connection_t));
 
 	if(!c)
@@ -74,10 +63,7 @@ connection_t *new_connection(void)
 	return c;
 }
 
-void free_connection(connection_t *c)
-{
-	cp();
-
+void free_connection(connection_t *c) {
 	if(c->name)
 		free(c->name);
 
@@ -118,47 +104,35 @@ void free_connection(connection_t *c)
 	free(c);
 }
 
-void connection_add(connection_t *c)
-{
-	cp();
-
+void connection_add(connection_t *c) {
 	avl_insert(connection_tree, c);
 }
 
-void connection_del(connection_t *c)
-{
-	cp();
-
+void connection_del(connection_t *c) {
 	avl_delete(connection_tree, c);
 }
 
-void dump_connections(void)
-{
+void dump_connections(void) {
 	avl_node_t *node;
 	connection_t *c;
 
-	cp();
-
-	logger(LOG_DEBUG, _("Connections:"));
+	logger(LOG_DEBUG, "Connections:");
 
 	for(node = connection_tree->head; node; node = node->next) {
 		c = node->data;
-		logger(LOG_DEBUG, _(" %s at %s options %lx socket %d status %04x outbuf %d/%d/%d"),
-			   c->name, c->hostname, c->options, c->socket, c->status.value,
+		logger(LOG_DEBUG, " %s at %s options %x socket %d status %04x outbuf %d/%d/%d",
+			   c->name, c->hostname, c->options, c->socket, bitfield_to_int(&c->status, sizeof c->status),
 			   c->outbufsize, c->outbufstart, c->outbuflen);
 	}
 
-	logger(LOG_DEBUG, _("End of connections."));
+	logger(LOG_DEBUG, "End of connections.");
 }
 
-bool read_connection_config(connection_t *c)
-{
+bool read_connection_config(connection_t *c) {
 	char *fname;
 	int x;
 
-	cp();
-
-	asprintf(&fname, "%s/hosts/%s", confbase, c->name);
+	xasprintf(&fname, "%s/hosts/%s", confbase, c->name);
 	x = read_config_file(c->config_tree, fname);
 	free(fname);
 
